#
# spec file for package ghc-http-api-data
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name http-api-data
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.6.1
Release:        1.1
Summary:        Converting to/from HTTP API data like URL pieces, headers and query parameters
License:        BSD-2-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-cookie-devel
BuildRequires:  ghc-cookie-prof
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-hashable-prof
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-http-types-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-tagged-devel
BuildRequires:  ghc-tagged-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-iso8601-devel
BuildRequires:  ghc-text-iso8601-prof
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-time-compat-devel
BuildRequires:  ghc-time-compat-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-unordered-containers-prof
BuildRequires:  ghc-uuid-types-devel
BuildRequires:  ghc-uuid-types-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
BuildRequires:  ghc-quickcheck-instances-devel
BuildRequires:  ghc-quickcheck-instances-prof
%endif

%description
This package defines typeclasses used for converting Haskell data types to and
from HTTP API data.

Please see README.md.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Wed May 22 2024 Peter Simons <psimons@suse.com>
- Update http-api-data to version 0.6.1.
  0.6.1
  * Require at least GHC-8.6
  * Support `cookie-0.5.0`, see [#137](https://github.com/fizruk/http-api-data/pull/137).
    Note that `cookie-0.5.0`'s parser now removes double quotes around cookie values.
* Wed Oct 11 2023 Peter Simons <psimons@suse.com>
- Update http-api-data to version 0.6 revision 1.
  0.6
  - --
  * Use [`text-iso8601`](https://hackage.haskell.org/package/text-iso8601)
    to parse and serialise `time` types. (Instead of `attoparsec-iso8601`).
    Due this change some formats are slightly changed:
  - Space between timezone is not accepted
  - Timezone offset can be between -23:59..23:59
  - Timezone offset is output with colon between hours and minutes
  * Require at least GHC-8.2
  0.5.1
  - ----
  * Add `toEncodedQueryParam` to `ToHttpApiData` type class. It has default
    implementation using `toQueryParam`, but may be overriden with more efficient
    one.
* Wed Jun 21 2023 Peter Simons <psimons@suse.com>
- Relax overspecified constraint on base-compat.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Tue Aug 23 2022 Peter Simons <psimons@suse.com>
- Update http-api-data to version 0.5 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Jun 15 2022 Peter Simons <psimons@suse.com>
- Update http-api-data to version 0.5.
  0.5
  - --
  * Use `attoparsec-iso8601-1.1.0.0`.
    `Day` and `UTCTime` parsers require at least 4 digits now, which is a breaking change.
  * Drop GHC-7.8 and GHC-7.10 support.
* Tue Jan  4 2022 Peter Simons <psimons@suse.com>
- Update http-api-data to version 0.4.3 revision 6.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov 15 2021 psimons@suse.com
- Update http-api-data to version 0.4.3 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Sep  2 2021 psimons@suse.com
- Update http-api-data to version 0.4.3 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Apr  6 2021 Ondřej Súkup <mimi.vx@gmail.com>
- fix license to BSD-2-Clause
* Wed Mar 24 2021 psimons@suse.com
- Update http-api-data to version 0.4.3 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Feb 21 2021 psimons@suse.com
- Update http-api-data to version 0.4.3 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Jan  4 2021 psimons@suse.com
- Update http-api-data to version 0.4.3.
  0.4.3
  - ----
  * Add `Quarter`, `QuarterOfYear` and `Month` instances
  * Support `bytestring-0.11`
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Sun Aug 30 2020 psimons@suse.com
- Update http-api-data to version 0.4.2.
  0.4.2
  - ----
  * Add instances for `Const` and `Identity`
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add http-api-data at version 0.4.1.1.
